==> red5pro-0.0.1.tar.gz: example/lib/stream_player_view.dart <==
import 'package:flutter/material.dart';
import 'package:red5pro/red5_configuration.dart';
import 'package:red5pro/red5_stream_player_view.dart';

class StreamPlayerView extends StatefulWidget {
  const StreamPlayerView({Key? key}) : super(key: key);

  @override
  _StreamPlayerViewState createState() => _StreamPlayerViewState();
}

class _StreamPlayerViewState extends State<StreamPlayerView> {
  late R5StreamPlayerViewController controller;
  bool isPlaying = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Red5Pro Player'),
      ),
      body: Column(
        children: [
          Expanded(
            child: Red5StreamPlayerView(
              red5configuration: Red5Configuration(
                licenseKey: 'MWFI-5693-YK4B-1FDG',
                protocol: R5StreamProtocol.RTSP,
                host: '159.223.78.142',
                port: 8554,
              ),
              streamName: 'red5prostream',
              onR5StreamPlayerViewCreated: (controller) {
                this.controller = controller;
              },
            ),
          ),
          SizedBox(
            width: double.maxFinite,
            child: TextButton(
              child: Text(isPlaying ? 'Stop' : 'Play'),
              onPressed: () {
                if (isPlaying) {
                  controller.stop();
                } else {
                  controller.play();
                }
              },
            ),
          )
        ],
      ),
    );
  }
}

==> red5pro-0.0.14.tar.gz: example/lib/stream_player_view.dart <==
import 'package:flutter/material.dart';
import 'package:red5pro/red5_configuration.dart';
import 'package:red5pro/red5_stream_player_view.dart';

class StreamPlayerView extends StatefulWidget {
  final Red5Configuration red5configuration;
  final String streamName;

  const StreamPlayerView(
      {required this.red5configuration, required this.streamName, Key? key})
      : super(key: key);

  @override
  _StreamPlayerViewState createState() => _StreamPlayerViewState();
}

class _StreamPlayerViewState extends State<StreamPlayerView> {
  late R5StreamPlayerViewController controller;
  bool isPlaying = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Red5Pro Player'),
      ),
      body: Column(
        children: [
          Expanded(
            child: Red5StreamPlayerView(
              red5configuration: widget.red5configuration,
              streamName: widget.streamName,
              onR5StreamPlayerViewCreated: (controller) {
                this.controller = controller;
              },
            ),
          ),
          SizedBox(
            width: double.maxFinite,
            child: TextButton(
              child: Text(isPlaying ? 'Stop' : 'Play'),
              onPressed: () {
                if (isPlaying) {
                  controller.stop().then((value) {
                    setState(() {
                      isPlaying = false;
                    });
                  });
                } else {
                  controller.play().then((value) {
                    setState(() {
                      isPlaying = true;
                    });
                  });
                }
              },
            ),
          )
        ],
      ),
    );
  }
}
